MAIN_NET_NETWORK_ID = 1029
TEST_NET_NETWORK_ID = 1

MAIN_NET_CHAIN_ID = 1029
TEST_NET_CHAIN_ID = 1

NULL_ADDRESS_BYTES = bytes(20)
NULL_ADDRESS_HEX = "0x0000000000000000000000000000000000000000"

DEFAULT_GAS_PRICE = 1

EARLIEST = "earliest"
LATEST_CHECKPOINT = "latest_checkpoint"
LATEST_CONFIRMED = "latest_confirmed"
LATEST_STATE = "latest_state"
LATEST_MINED = "latest_mined"